@@ -32,7 +32,7 @@
 // - NN = real(~ISNAN(X)')*sparse(diag(W))*real(~ISNAN(Y))   count of valid (non-NaN) elements
 //        computed more efficiently 
 //
-//    $Id: covm_mex.cpp 12877 2015-09-12 14:16:39Z schloegl $
+//    $Id: covm_mex.cpp 12888 2015-12-22 10:28:53Z schloegl $
 //    Copyright (C) 2009,2010,2011 Alois Schloegl <alois.schloegl@gmail.com>
 //    This function is part of the NaN-toolbox
 //    http://pub.ist.ac.at/~schloegl/matlab/NaN/
@@ -54,6 +54,10 @@
  */
 #define ISNAN(a) (a!=a)
 
+#ifndef typeof
+#define typeof __typeof__
+#endif
+
 void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const mxArray *PInputs[]) 
 {
     	double 		*X0=NULL, *Y0=NULL, *W=NULL;
@@ -830,7 +834,7 @@ void mexFunction(int POutputCount,  mxArray* POutput[], int PInputCount, const m
     		case mxSTRUCT_CLASS:
 #endif
     		default: 
-    			mexPrintf("Type of 3rd input argument cannot be used to return status of NaN occurence.");
+    			mexPrintf("Type of 3rd input argument cannot be used to return status of NaN occurrence.");
 		}
 	}
 #endif
